@@ -1022,7 +1022,6 @@ print_page(int                 const s,
            bool                const doMediaDestination,
            int                 const mediaDestination) 
 {
-    unsigned char palette[2]={0,255};
     float xpos=xoffs,ypos=yoffs;
     if(doDuplex) {
         xl_ubyte(s,duplex);  xl_attr_ubyte(s,aDuplexPageMode);
@@ -1038,8 +1037,6 @@ print_page(int                 const s,
     xl_ubyte(s,format); xl_attr_ubyte(s,aMediaSize);
     XL_Operator(s,oBeginPage);
         xl_ubyte(s,img->colorSpace); xl_attr_ubyte(s,aColorSpace);   
-        xl_ubyte(s,e8Bit); xl_attr_ubyte(s,aPaletteDepth);   
-        xl_ubyte_array(s,palette,2); xl_attr_ubyte(s,aPaletteData);  
         XL_Operator(s,oSetColorSpace);
         
         if(center) {
