@@ -24,6 +24,7 @@ x**  - mymalloc() and check_and_rotate() functions for often used
 
 #include "ppm.h"
 #include "nstring.h"
+#include "mallocvar.h"
 
 #include "mitsu.h"
 
@@ -50,7 +51,6 @@ static void lookuptabledata(int cols, int rows, int enlarge,
                             struct mediasize medias);
 static void check_and_rotate(int cols, int rows, int enlarge,
                              struct mediasize medias);
-static void * mymalloc(long bytes);
 #define CONST const
 #else /*__STDC__*/
 static int lineputinit();
@@ -58,7 +58,6 @@ static int lookuptableinit();
 static int lookuptabledata();
 static int frametransferinit();
 static int check_and_rotate();
-static char *mymalloc();
 #define CONST
 #endif
 
@@ -175,9 +174,9 @@ int main( argc, argv )
 
         ppm_readppminit(ifp, &cols, &rows, &maxval, &format);
         pixelrow = (pixel *) ppm_allocrow(cols);
-        redrow = mymalloc(cols * sizeof(char));
-        greenrow = mymalloc(cols * sizeof(char));
-        bluerow = mymalloc(cols * sizeof(char));
+        MALLOCARRAY_NOFAIL(redrow, cols);
+        MALLOCARRAY_NOFAIL(greenrow, cols);
+        MALLOCARRAY_NOFAIL(bluerow, cols);
         lineputinit(cols, rows, sharpness, enlarge, copy, medias);
 
         for ( row = 0; row < rows; ++row ) {
@@ -223,16 +222,20 @@ int main( argc, argv )
 
         /* first check wether we can use the lut transfer */
 
-        table = ppm_computecolorhist(pixelpic, cols, rows, MAXLUTCOL+1, &colanz);
+        table = ppm_computecolorhist(pixelpic, cols, rows, MAXLUTCOL+1, 
+                                     &colanz);
         if (table != NULL) {
-            hashinfo *colorhashtable = (hashinfo *)mymalloc(HASHSIZE * sizeof(hashinfo));
+            hashinfo *colorhashtable;
+
+            MALLOCARRAY_NOFAIL(colorhashtable, HASHSIZE);
             for (i=0; i<HASHSIZE; i++) {
                 colorhashtable[i].flag = -1;
                 colorhashtable[i].next = NULL;
             }
 
             /* we can use the lookuptable */
-            pm_message("found %d colors - using the lookuptable-method",colanz);
+            pm_message("found %d colors - using the lookuptable-method",
+                       colanz);
             lookuptableinit(sharpness, enlarge, copy, medias);
             switch(PPM_FORMAT_TYPE(format)) {
             /* color */
@@ -252,8 +255,7 @@ int main( argc, argv )
                     else {
                         while (hashrun->next != NULL)
                             hashrun = hashrun->next;
-                        hashrun->next =
-                            (struct hashinfo *) mymalloc(sizeof(struct hashinfo));
+                        MALLOCVAR_NOFAIL(hashrun->next);
                         hashrun = hashrun->next;
                         hashrun->color = (table[colval]).color;
                         hashrun->flag  = colval;
@@ -278,8 +280,7 @@ int main( argc, argv )
                     else {
                         while (hashrun->next != NULL)
                             hashrun = hashrun->next;
-                        hashrun->next =
-                            (struct hashinfo *) mymalloc(sizeof(struct hashinfo));
+                        MALLOCVAR_NOFAIL(hashrun->next);
                         hashrun = hashrun->next;
                         hashrun->color = (table[colval]).color;
                         hashrun->flag  = colval;
@@ -566,25 +567,6 @@ static int frametransferinit(cols, rows, sharpness, enlarge, copy, medias)
 }
 
 
-#ifdef __STDC__
-static void *
-mymalloc(long bytes)
-#else
-static char *
-mymalloc(bytes)
-    long bytes;
-#endif
-{
-    void *mem;
-
-    mem = malloc(bytes);
-    if( mem == NULL )
-        pm_error("out of memory allocating %ld bytes", bytes);
-
-    return mem;
-}
-
-
 #ifdef __STDC__
 static void
 check_and_rotate(int cols, int rows, int enlarge, struct mediasize medias)
