@@ -14,6 +14,9 @@
 ** 03/2003 - Added 24+32 bpp support.
 */
 
+#define _BSD_SOURCE 1      /* Make sure strdup() is in string.h */
+#define _XOPEN_SOURCE 500  /* Make sure strdup() is in string.h */
+
 #include <math.h>
 #include <string.h>
 #include <assert.h>
@@ -21,6 +24,7 @@
 #include "ppm.h"
 #include "shhopt.h"
 #include "nstring.h"
+#include "mallocvar.h"
 #include "winico.h"
 
 #define MAJVERSION 0
@@ -162,10 +166,15 @@ static u1 *
 readU1String (int length)
 {
    
-    u1 * string = malloc (sizeof (u1) * (length+1));
+    u1 * string;
+    
+    MALLOCARRAY(string, length + 1);
+    if (string == NULL)
+        pm_error("out of memory");
+
     fread(string,sizeof(u1),length,ifp);
     string[length] = 0;
-    file_offset += length;
+    file_offset += length * sizeof(u1);
     return string;
 }
 
@@ -184,7 +193,13 @@ readU4 (void) {
 static IC_Entry 
 readICEntry (void) 
 {
-    IC_Entry entry = malloc ( sizeof (* entry) );
+    IC_Entry entry;
+
+    MALLOCVAR(entry);
+
+    if (entry == NULL)
+        pm_error("Unable to allcoate memory for IC entry");
+
     entry->width         = readU1();
     entry->height        = readU1();
     entry->color_count   = readU1();
@@ -206,7 +221,13 @@ readICEntry (void)
 static IC_InfoHeader 
 readInfoHeader (IC_Entry entry) 
 {
-    IC_InfoHeader ih = malloc ( sizeof (* ih) );
+    IC_InfoHeader ih;
+
+    MALLOCVAR(ih);
+    
+    if (ih == NULL)
+        pm_error("Unable to allocate memory for info header");
+
     ih->size            = readU4();
     ih->width           = readU4();
     ih->height          = readU4();
@@ -238,7 +259,13 @@ readInfoHeader (IC_Entry entry)
 static IC_Color 
 readICColor (void) 
 {
-    IC_Color col = malloc ( sizeof (* col) );
+    IC_Color col;
+
+    MALLOCVAR(col);
+
+    if (col == NULL)
+        pm_error("Unable to allocate memory for color");
+
     col->blue     = readU1();
     col->green    = readU1();
     col->red      = readU1();
@@ -261,8 +288,13 @@ read1Bitmap (int width, int height)
 {
     int tmp;
     int xBytes;
-    u1 * bitmap = malloc ( (width * height ) * (sizeof (u1)) );
+    u1 * bitmap;
     int wt = width;
+
+    MALLOCARRAY(bitmap, width * height);
+    if (bitmap == NULL)
+        pm_error("out of memory");
+
     wt >>= 3;
     if (wt & 3) {
         wt = (wt & ~3) + 4;
@@ -294,9 +326,16 @@ static u1 *
 read4Bitmap (int width, int height) 
 {
     int tmp;
-    u1 * bitmap = malloc ( (width * height ) * (sizeof (u1)) );
+    u1 * bitmap;
+
     int wt = width;
     int xBytes;
+
+    MALLOCARRAY(bitmap, width * height);
+    if (bitmap == NULL)
+        pm_error("out of memory");
+
+
     wt >>= 1;
     if (wt & 3) {
         wt = (wt & ~3) + 4;
@@ -333,8 +372,12 @@ read8Bitmap (int width, int height)
     int tmp;
     unsigned int xBytes;
     unsigned int wt = width;
-    u1 * bitmap = malloc ( (width * height ) * (sizeof (u1)) );
+    u1 * bitmap;
    
+    MALLOCARRAY(bitmap, width * height);
+    if (bitmap == NULL)
+        pm_error("out of memory");
+
     if (wt & 3) {
         wt = (wt & ~3) + 4;
     }
@@ -352,34 +395,52 @@ read8Bitmap (int width, int height)
     return bitmap;
 }
 
+
+
 /*
  * Read a true color bitmap. (24/32 bits)
  * 
  * The output routine deplanarizes it for us, we keep it flat here.
  */
 static u1 *
-readXBitmap (int width, int height, int bpp)
-{
-    int tmp = 0;
-    int bytes = bpp >> 3;
-    u1 * bitmap = malloc ( (bytes * width * height ) * (sizeof (u1)) );
-    /* remember - bmp (dib) stored upside down, so reverse */
-    u1 * bitcurptr = bitmap + (bytes * width * (height-1) ) * (sizeof (u1));
-    unsigned int xBytes = width * bytes;
+readXBitmap (int const width, 
+             int const height, 
+             int const bpp) {
+    int          const bytes  = bpp >> 3;
+    unsigned int const xBytes = width * bytes;
 
-    for (tmp = 0;tmp < height; tmp++, bitcurptr -= xBytes) {
-        u1 * row = readU1String(xBytes);
-        memcpy(bitcurptr, row, xBytes);
-        free(row);
+    u1 * bitmap;
+        /* remember - bmp (dib) stored upside down, so reverse */
+
+    MALLOCARRAY(bitmap, bytes * width * height);
+    if (bitmap == NULL)
+        pm_error("out of memory allocating bitmap array");
+
+    {
+        unsigned int i;
+        u1 * bitcurptr;
+
+        for (i = 0, bitcurptr = &bitmap[bytes * width * (height-1)];
+             i < height; 
+             ++i, bitcurptr -= xBytes) {
+
+            u1 * const row = readU1String(xBytes);
+            memcpy(bitcurptr, row, xBytes);
+            free(row);
+        }
     }
     return bitmap;
 }
 
+
+
 static MS_Ico 
 readIconFile (bool const verbose) {
     int iter,iter2;
 
-    MS_Ico MSIconData= malloc( sizeof (* MSIconData) );
+    MS_Ico MSIconData;
+
+    MALLOCVAR(MSIconData);
    
     /*
      * reserved - should equal 0.
@@ -397,8 +458,11 @@ readIconFile (bool const verbose) {
      * Allocate "count" array of entries.
      */
     if (verbose) 
-        fprintf (stderr,"Icon file contains %d icons.\n",MSIconData->count);
-    MSIconData->entries  = malloc (MSIconData->count * sizeof(IC_Entry *));
+        pm_message("Icon file contains %d icons.", MSIconData->count);
+
+    MALLOCARRAY(MSIconData->entries, MSIconData->count);
+    if (MSIconData->entries == NULL)
+        pm_error("out of memory");
     /*
      * Read in each of the entries
      */
@@ -408,7 +472,8 @@ readIconFile (bool const verbose) {
     /* After that, we have to read in the infoheader, color map (if
      * any) and the actual bit/pix maps for the icons.  
      */
-    if (verbose) fprintf (stderr,"#\tColors\tBPP\tWidth\tHeight\n");
+    if (verbose) 
+        fprintf (stderr,"#\tColors\tBPP\tWidth\tHeight\n");
     for (iter = 0;iter < MSIconData->count ; iter++ ) {
         int bpp;
         MSIconData->entries[iter]->ih =
@@ -423,9 +488,11 @@ readIconFile (bool const verbose) {
             /* 24/32 bpp icon has no palette */
             break;
         default:
-            MSIconData->entries[iter]->colors = 
-                malloc (MSIconData->entries[iter]->color_count * 
-                        sizeof(IC_Color *));
+            MALLOCARRAY(MSIconData->entries[iter]->colors, 
+                        MSIconData->entries[iter]->color_count);
+            if (MSIconData->entries[iter]->colors == NULL)
+                pm_error("out of memory");
+
             for (iter2 = 0;
                  iter2 < MSIconData->entries[iter]->color_count ; 
                  iter2++ ) {
@@ -504,8 +571,7 @@ trimOutputName(const char inputName[])
      * Just trim off the final ".ppm", if there is one, else return as is.
      * oh, for =~ ... :)
      */
-    char * outFile = malloc ( sizeof (char) * (strlen (inputName) + 1));
-    strcpy(outFile, inputName);
+    char * outFile = strdup(inputName);
     if (!strcmp (outFile + (strlen (outFile) - 4), ".ppm")) {
         *(outFile + (strlen (outFile) - 4)) = 0;
     }
