@@ -286,7 +286,16 @@ shearYNoAntialias(xel **           const inxels,
    row, it would be one page per output row plus one page per input row.
 -----------------------------------------------------------------------------*/
     int inrow;
+    unsigned int outrow;
 
+    /* Fill the output with background */
+    for (outrow = 0; outrow < outrows; ++outrow) {
+        unsigned int col;
+        for (col = 0; col < cols; ++col)
+            outxels[outrow][col] = bgxel;
+    }
+
+    /* Overlay that background with sheared image */
     for (inrow = 0; inrow < inrows; ++inrow) {
         int col;
         for (col = 0; col < cols; ++col) {
@@ -295,24 +304,6 @@ shearYNoAntialias(xel **           const inxels,
                 outxels[outrow][col] = inxels[inrow][col];
         }
     }
-    {
-        /* Now fill in the pixels that we didn't fill above, with background */
-        int col;
-        for (col = 0; col < cols; ++col) {
-            int startBgRow, endBgRow;
-            int outrow;
-            
-            if (shearParm[col].intnew0 > 0 ) {
-                startBgRow = 0;
-                endBgRow   = shearParm[col].intnew0;
-            } else {
-                startBgRow = outrows + shearParm[col].intnew0;
-                endBgRow   = outrows;
-            }
-            for (outrow = startBgRow; outrow < endBgRow; ++outrow)
-                outxels[outrow][col] = bgxel;
-        }
-    }
 }
 
 
