@@ -21,7 +21,7 @@ struct cmdlineInfo {
     /* All the information the user supplied in the command line,
        in a form easy for the program to use.
     */
-    char *inputFilename;
+    const char * inputFilename;
     pixel maskColor;
     unsigned int verbose;
 };
@@ -59,12 +59,9 @@ parseCommandLine(int argc, char ** argv,
     cmdlineP->maskColor = ppm_parsecolor(argv[1], PPM_MAXMAXVAL);
 
     if (argc - 1 == 1)
-        cmdlineP->inputFilename = NULL;  /* he wants stdin */
+        cmdlineP->inputFilename = "-";  /* he wants stdin */
     else if (argc - 1 == 2) {
-        if (strcmp(argv[2], "-") == 0)
-            cmdlineP->inputFilename = NULL;  /* he wants stdin */
-        else 
-            cmdlineP->inputFilename = strdup(argv[2]);
+        cmdlineP->inputFilename = argv[2];
     } else 
         pm_error("Too many arguments.  The only arguments accepted\n"
                  "are the mask color and optional input file specificaton");
